#...
Displaying notes found in: .note.gnu.property
[ 	]+Owner[ 	]+Data size[ 	]+Description
  GNU                  0x[0-9a-f]+	NT_GNU_PROPERTY_TYPE_0
      Properties: stack size: 0x800000
	x86 ISA needed: x86-64-baseline, x86-64-v2, x86-64-v4
	x86 feature used: x86
	x86 ISA used: x86-64-baseline, x86-64-v2, x86-64-v4
#pass
